@@ -6,7 +6,7 @@
 #
 # $Id$
 #
-# Copyright B. Cornec 2007-2012
+# Copyright B. Cornec 2007-2015
 # Eric Anderson's changes are (c) Copyright 2012 Hewlett Packard
 # Provided under the GPL v2
 
@@ -219,7 +219,7 @@ while (<FILE>) {
 			if (defined $pb->{'patches'}->{$tuple}) {
 				my ($patchcmd,$patchopt) = pb_distro_get_param($pb->{'pbos'},pb_conf_get_if("ospatchcmd","ospatchopt"));
 				foreach my $p (split(/,/,$pb->{'patches'}->{$tuple})) {
-					pb_log(3,"DEBUG($tuple) Adding patch command $i\n");
+					pb_log(3,"DEBUG($tuple) Adding patch command $i ($patchopt)\n");
 					print DEST "%patch$i $patchopt\n";
 					$i++;
 				}
